@@ -5,8 +5,7 @@ use File::Spec;
 
 package App::GUI::Cellgraph::Config;
 
-my $file_name = File::Spec->catfile( File::HomeDir->my_home, '.config', 'cellgraph');
-
+my $file = '.cellgraph';
 my $dir = '';
 my $default = {
     file_base_dir => '~',
@@ -17,12 +16,8 @@ my $default = {
     write_dir => '~',
     last_settings => [],
     color_set => {
-        grey => ['#FFF', '#DDD', '#BBB', '#999', '#777','#555', '#333', '#111' ],
-        basic  => ['#FFF', '#F00', '#0F0', '#00F', '#FF0', '#0FF', '#F0F','#000' ],
-        dawn   => [ 'white', '#f9d87b', '#936d1a', '#bf3136', '#8f1416', '#99158b', '#1d1d7c', '#111111', 'black' ],
-        day    => [ 'white', '#ffcf3d', '#e25555', '#e65c60', '#4acfab', '#48614a', 'gray20',  '#111111', 'black' ],
-        skye   => [ 'white', '#ffcf3d', '#173fab', '#8e8e8e', '#8e8e8e', '#8e8e8e', '#8e8e8e', '#8e8e8e', 'black' ],
-        sunset => [ 'white', '#f9d87b', '#936d1a', '#bf3136', '#94148e', '#c3baee', '#1d1d7c', '#111111', 'black' ],
+        grey => ['#FFF', '#BBB', '#888', '#444','#000' ],
+        basic => ['#FFF', '#F00', '#0F0', '#00F','#000' ],
     },
     color => {
         bright_blue      => [  98, 156, 249],
@@ -184,29 +179,30 @@ my $default = {
 
 sub new {
     my ($pkg) = @_;
-    my $data = -r $file_name
-             ? load( $pkg, $file_name )
+    for my $d ('.', File::HomeDir->my_home, File::HomeDir->my_documents){
+        my $path = File::Spec->catfile( $d, $file );
+        $dir = $d, last if -r $path;
+    }
+    my $data = $dir
+             ? load( $pkg, File::Spec->catfile( $dir, $file ) )
              : $default;
-    bless { path => $file_name, data => $data };
+    $dir ||= File::HomeDir->my_home;
+    bless { path => File::Spec->catfile( $dir, $file ), data => $data };
 }
 
 sub load {
     my ($self, $file) = @_;
     my $data = {};
     open my $FH, '<', $file or return "could not read $file: $!";
-    my $category = '';
+    my $cat = '';
     while (<$FH>) {
         chomp;
         next unless $_ or substr( $_, 0, 1) eq '#';
-        if    (/^\s*(\w+):\s*$/)          { $category = $1; $data->{$category} = []; }
-        elsif (/^\s+-\s+(.+)\s*$/)        { push @{$data->{$category}}, $1;          }
-        elsif (/^\s+\+\s+(\w+)\s*=\s*\[\s*(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*\]/)
-                                          { $data->{$category} = {} if ref $data->{$category} ne 'HASH';
-                                            $data->{$category}{$1} = [$2, $3, $4];   }
+        if    (/^\s*(\w+):/)              { $cat = $1 }
         elsif (/^\s+\+\s+(\w+)\s*=\s*\[\s*(.+)\s*\]/)
-                                          { $data->{$category} = {} if ref $data->{$category} ne 'HASH';
-                                            $data->{$category}{$1} = [map {tr/ //d; $_} split /,/, $2] }
-        elsif (/\s*(\w+)\s*=\s*(.+)\s*$/) { $data->{$1} = $2; $category =  '';}
+                                          { $data->{$cat}{$1} = [map {tr/ //d; $_} split /,/, $2] }
+        elsif (/^\s+-\s+(.+)\s*$/)        { push @{$data->{$cat}}, $1;          }
+        elsif (/\s*(\w+)\s*=\s*(.+)\s*$/) { $data->{$1} = $2; $cat = ''         }
     }
     close $FH;
     $data;
